==> owncloud-10.0.7.tgz: owncloud/lib/l10n/cy_GB.js <==
OC.L10N.register(
    "lib",
    {
    "today" : "heddiw",
    "yesterday" : "ddoe",
    "last month" : "mis diwethaf",
    "last year" : "y llynedd",
    "seconds ago" : "eiliad yn ôl",
    "None" : "Dim",
    "Username" : "Enw defnyddiwr",
    "Password" : "Cyfrinair",
    "Apps" : "Pecynnau",
    "General" : "Cyffredinol",
    "Encryption" : "Amgryptiad",
    "Search" : "Chwilio",
    "%s enter the database username." : "%s rhowch enw defnyddiwr y gronfa ddata.",
    "%s enter the database name." : "%s rhowch enw'r gronfa ddata.",
    "%s you may not use dots in the database name" : "%s does dim hawl defnyddio dot yn enw'r gronfa ddata",
    "Oracle username and/or password not valid" : "Enw a/neu gyfrinair Oracle annilys",
    "DB Error: \"%s\"" : "Gwall DB: \"%s\"",
    "Offending command was: \"%s\"" : "Y gorchymyn wnaeth beri tramgwydd oedd: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Rhaid i chi naill ai gyflwyno cyfrif presennol neu'r gweinyddwr.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Y gorchymyn wnaeth beri tramgwydd oedd: \"%s\", enw: %s, cyfrinair: %s",
    "PostgreSQL username and/or password not valid" : "Enw a/neu gyfrinair PostgreSQL annilys",
    "Set an admin username." : "Creu enw defnyddiwr i'r gweinyddwr.",
    "Set an admin password." : "Gosod cyfrinair y gweinyddwr.",
    "Could not find category \"%s\"" : "Methu canfod categori \"%s\"",
    "Help" : "Cymorth",
    "Settings" : "Gosodiadau",
    "Users" : "Defnyddwyr",
    "web services under your control" : "gwasanaethau gwe a reolir gennych",
    "Application is not enabled" : "Nid yw'r pecyn wedi'i alluogi",
    "Authentication error" : "Gwall dilysu",
    "Token expired. Please reload page." : "Tocyn wedi dod i ben. Ail-lwythwch y dudalen."
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/cy_GB.js <==
OC.L10N.register(
    "lib",
    {
    "today" : "heddiw",
    "yesterday" : "ddoe",
    "last month" : "mis diwethaf",
    "last year" : "y llynedd",
    "seconds ago" : "eiliad yn ôl",
    "None" : "Dim",
    "Username" : "Enw defnyddiwr",
    "Password" : "Cyfrinair",
    "Apps" : "Pecynnau",
    "General" : "Cyffredinol",
    "Encryption" : "Amgryptiad",
    "Search" : "Chwilio",
    "%s enter the database username." : "%s rhowch enw defnyddiwr y gronfa ddata.",
    "%s enter the database name." : "%s rhowch enw'r gronfa ddata.",
    "%s you may not use dots in the database name" : "%s does dim hawl defnyddio dot yn enw'r gronfa ddata",
    "Oracle username and/or password not valid" : "Enw a/neu gyfrinair Oracle annilys",
    "DB Error: \"%s\"" : "Gwall DB: \"%s\"",
    "Offending command was: \"%s\"" : "Y gorchymyn wnaeth beri tramgwydd oedd: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Rhaid i chi naill ai gyflwyno cyfrif presennol neu'r gweinyddwr.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Y gorchymyn wnaeth beri tramgwydd oedd: \"%s\", enw: %s, cyfrinair: %s",
    "PostgreSQL username and/or password not valid" : "Enw a/neu gyfrinair PostgreSQL annilys",
    "Set an admin username." : "Creu enw defnyddiwr i'r gweinyddwr.",
    "Set an admin password." : "Gosod cyfrinair y gweinyddwr.",
    "Could not find category \"%s\"" : "Methu canfod categori \"%s\"",
    "Help" : "Cymorth",
    "Settings" : "Gosodiadau",
    "Users" : "Defnyddwyr",
    "web services under your control" : "gwasanaethau gwe a reolir gennych",
    "Application is not enabled" : "Nid yw'r pecyn wedi'i alluogi",
    "Authentication error" : "Gwall dilysu",
    "Token expired. Please reload page." : "Tocyn wedi dod i ben. Ail-lwythwch y dudalen.",
    "Imprint" : "Imprint"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
